/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Tinderbox Status Summary.
 *
 * The Initial Developer of the Original Code is
 * Mark Banner <bugzilla@standard8.demon.co.uk>.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

let gPrefBranch = Components.classes["@mozilla.org/preferences-service;1"]
                            .getService(Components.interfaces.nsIPrefBranch);

var bundle = srGetStrBundle("chrome://customcalendardefaults/locale/ccd-prefs.properties");

function toggleEventUI() {
  var ccdCheckEventPrivacy = document.getElementById("ccdCheckEventPrivacy");
  var ccdSetEventPrivacy = document.getElementById("ccdSetEventPrivacy");
  var hideableItems = new Array();
  hideableItems = ccdSetEventPrivacy.getElementsByAttribute("hideable", true);
  if (ccdCheckEventPrivacy.hasAttribute("checked", true)) {
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (item.hasAttribute("disabled", true)) {
  	    item.removeAttribute("disabled");
	  }
    }
  }
  else {
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (!item.hasAttribute("disabled", true)) {
  	    item.setAttribute("disabled", true);
	  }
    }
  }
}

function toggleTaskUI() {
  var ccdCheckTaskPrivacy = document.getElementById("ccdCheckTaskPrivacy");
  var ccdSetTaskPrivacy = document.getElementById("ccdSetTaskPrivacy");
  var hideableItems = new Array();
  hideableItems = ccdSetTaskPrivacy.getElementsByAttribute("hideable", true);
  if (ccdCheckTaskPrivacy.hasAttribute("checked", true)) {
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (item.hasAttribute("disabled", true)) {
  	    item.removeAttribute("disabled");
	  }
    }
  }
  else {
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (!item.hasAttribute("disabled", true)) {
  	    item.setAttribute("disabled", true);
	  }
    }
  }
}

function resetCalendarDefaults() {
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.event.status")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.event.status");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.event.privacy")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.event.privacy");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.event.privacy.state")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.event.privacy.state");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.event.priority")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.event.priority");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.task.status")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.task.status");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.task.privacy")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.task.privacy");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.task.privacy.state")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.task.privacy.state");
  }
  if (gPrefBranch.prefHasUserValue("extensions.customcalendardefaults.task.priority")) {
    void gPrefBranch.clearUserPref("extensions.customcalendardefaults.task.priority");
  }
  onLoadCcdPrefsPane();
}

function onLoadCcdPrefsPane() {
  var ccdEventPriority = document.getElementById("ccdEventPriority");
  var defaultEventPriority = gPrefBranch.getCharPref("extensions.customcalendardefaults.event.priority");
  var eventPriorityNone = bundle.GetStringFromName( "eventPriorityNone.label" );
  var eventPriorityLow = bundle.GetStringFromName( "eventPriorityLow.label" );
  var eventPriorityHigh = bundle.GetStringFromName( "eventPriorityHigh.label" );
  var eventPriorityNormal = bundle.GetStringFromName( "eventPriorityNormal.label" );
  if (defaultEventPriority == "0") {
    ccdEventPriority.setAttribute("label", eventPriorityNone);
  } else if (defaultEventPriority == "1") {
    ccdEventPriority.setAttribute("label", eventPriorityHigh);
  } else if (defaultEventPriority == "5") {
    ccdEventPriority.setAttribute("label", eventPriorityNormal);
  } else if (defaultEventPriority == "9") {
    ccdEventPriority.setAttribute("label", eventPriorityLow);
  }
  
  var ccdEventStatus = document.getElementById("ccdEventStatus");
  var defaultEventStatus = gPrefBranch.getCharPref("extensions.customcalendardefaults.event.status");
  var eventStatusNone = bundle.GetStringFromName( "eventStatusNone.label" );
  var eventStatusTentative = bundle.GetStringFromName( "eventStatusTentative.label" );
  var eventStatusConfirmed = bundle.GetStringFromName( "eventStatusConfirmed.label" );
  var eventStatusCancelled = bundle.GetStringFromName( "eventStatusCancelled.label" );
  if (defaultEventStatus == "") {
    ccdEventStatus.setAttribute("label", eventStatusNone);
  } else if (defaultEventStatus == "TENTATIVE") {
    ccdEventStatus.setAttribute("label", eventStatusTentative);
  } else if (defaultEventStatus == "CONFIRMED") {
    ccdEventStatus.setAttribute("label", eventStatusConfirmed);
  } else if (defaultEventStatus == "CANCELLED") {
    ccdEventStatus.setAttribute("label", eventStatusCancelled);
  }
  
  var ccdEventPrivacyPref = gPrefBranch.getBoolPref("extensions.customcalendardefaults.event.privacy");
  var ccdEventPrivacy = document.getElementById("ccdSetEventPrivacy");
  if (ccdEventPrivacyPref == false) {
    var hideableItems = new Array();
    hideableItems = ccdEventPrivacy.getElementsByAttribute("hideable", true);
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (!item.hasAttribute("disabled", true)) {
  	    item.setAttribute("disabled", true);
	  }
    }
  }
  
  var ccdEventPrivacy = document.getElementById("ccdEventPrivacy");
  var defaultEventPrivacy = gPrefBranch.getCharPref("extensions.customcalendardefaults.event.privacy.state");
  var eventPrivacyPrivate = bundle.GetStringFromName( "eventPrivacyPrivate.label" );
  var eventPrivacyConfidential = bundle.GetStringFromName( "eventPrivacyConfidential.label" );
  var eventPrivacyPublic = bundle.GetStringFromName( "eventPrivacyPublic.label" );
  if (defaultEventPrivacy == "PRIVATE") {
    ccdEventPrivacy.setAttribute("label", eventPrivacyPrivate);
  } else if (defaultEventPrivacy == "CONFIDENTIAL") {
    ccdEventPrivacy.setAttribute("label", eventPrivacyConfidential);
  } else if (defaultEventPrivacy == "PUBLIC") {
    ccdEventPrivacy.setAttribute("label", eventPrivacyPublic);
  } else {
    ccdEventPrivacy.setAttribute("label", "");
  }
  
  var ccdTaskPriority = document.getElementById("ccdTaskPriority");
  var defaultTaskPriority = gPrefBranch.getCharPref("extensions.customcalendardefaults.task.priority");
  var taskPriorityNone = bundle.GetStringFromName( "taskPriorityNone.label" );
  var taskPriorityLow = bundle.GetStringFromName( "taskPriorityLow.label" );
  var taskPriorityHigh = bundle.GetStringFromName( "taskPriorityHigh.label" );
  var taskPriorityNormal = bundle.GetStringFromName( "taskPriorityNormal.label" );
  if (defaultTaskPriority == "0") {
    ccdTaskPriority.setAttribute("label", taskPriorityNone);
  } else if (defaultTaskPriority == "1") {
    ccdTaskPriority.setAttribute("label", taskPriorityHigh);
  } else if (defaultTaskPriority == "5") {
    ccdTaskPriority.setAttribute("label", taskPriorityNormal);
  } else if (defaultTaskPriority == "9") {
    ccdTaskPriority.setAttribute("label", taskPriorityLow);
  }
  
  var ccdTaskStatus = document.getElementById("ccdTaskStatus");
  var defaultTaskStatus = gPrefBranch.getCharPref("extensions.customcalendardefaults.task.status");
  var taskStatusNone = bundle.GetStringFromName( "taskStatusNone.label" );
  var taskStatusAction = bundle.GetStringFromName( "taskStatusAction.label" );
  var taskStatusProcess = bundle.GetStringFromName( "taskStatusProcess.label" );
  var taskStatusCompleted = bundle.GetStringFromName( "taskStatusCompleted.label" );
  var taskStatusCancelled = bundle.GetStringFromName( "taskStatusCancelled.label" );
  if (defaultTaskStatus == "") {
    ccdTaskStatus.setAttribute("label", taskStatusNone);
  } else if (defaultTaskStatus == "NEEDS-ACTION") {
    ccdTaskStatus.setAttribute("label", taskStatusAction);
  } else if (defaultTaskStatus == "IN-PROCESS") {
    ccdTaskStatus.setAttribute("label", taskStatusProcess);
  } else if (defaultTaskStatus == "COMPLETED") {
    ccdTaskStatus.setAttribute("label", taskStatusCompleted);
  } else if (defaultTaskStatus == "CANCELLED") {
    ccdTaskStatus.setAttribute("label", taskStatusCancelled);
  }
  
  var ccdTaskPrivacy = document.getElementById("ccdTaskPrivacy");
  var defaultTaskPrivacy = gPrefBranch.getCharPref("extensions.customcalendardefaults.task.privacy.state");
  var taskPrivacyPrivate = bundle.GetStringFromName( "taskPrivacyPrivate.label" );
  var taskPrivacyConfidential = bundle.GetStringFromName( "taskPrivacyConfidential.label" );
  var taskPrivacyPublic = bundle.GetStringFromName( "taskPrivacyPublic.label" );
  if (defaultTaskPrivacy == "PRIVATE") {
    ccdTaskPrivacy.setAttribute("label", taskPrivacyPrivate);
  } else if (defaultTaskPrivacy == "CONFIDENTIAL") {
    ccdTaskPrivacy.setAttribute("label", taskPrivacyConfidential);
  } else if (defaultTaskPrivacy == "PUBLIC") {
    ccdTaskPrivacy.setAttribute("label", taskPrivacyPublic);
  } else {
    ccdTaskPrivacy.setAttribute("label", "");
  }
  
  var ccdTaskPrivacyPref = gPrefBranch.getBoolPref("extensions.customcalendardefaults.task.privacy");
  var ccdTaskPrivacy = document.getElementById("ccdSetTaskPrivacy");
  if (ccdTaskPrivacyPref == false) {
    var hideableItems = new Array();
    hideableItems = ccdTaskPrivacy.getElementsByAttribute("hideable", true);
    for (var i = 0; i < hideableItems.length; ++i) {
      var item = hideableItems[i];
	  if (!item.hasAttribute("disabled", true)) {
  	    item.setAttribute("disabled", true);
	  }
    }
  }
}
